function AVW2COR(fname,pathlocation)
% Converts an AVW volume to COR-* files
% AVW2COR function to translate an 8-bit
% uchar AVW file to a series of MGH-style 
% COR files that also have an 8-bit uchar 
% datatype.
% Example: AVW2COR('Registered3Mean.img','/data9/tim/Surfaces/spgr_one')
% will read in the volume RegisteredVol.img
% and output files named /data9/tim/Surfaces/COR-[0-256]*
% Written 1/21/99: Timothy M. Ellmore, LBC/NIMH

% an afni BRIK may be formed from the resulting COR files with the command
%to3d -anat -prefix raw -session $SUBJECTS_DIR/$subjname/afni \
%         -view orig -datum byte -orient LSP $SUBJECTS_DIR/$subjname/mri/orig/COR-\[0-256]\*

% for MGH flattening COR files have these dimensions
xdim = 256;
ydim = 256;
zdim = 256;

% datatype is always 8-bit uchar for MGH COR files
type = 'uchar';

disp(['Reading volume: ' fname ' . . .'])

fid = fopen(fname, 'rb');
Volume = fread(fid, [xdim * ydim * zdim], type);
fclose(fid);

disp(['Done reading, max: ' num2str(max(Volume(:))) '  min: '  num2str(min(Volume(:))) ])

% form volume matrix (X,Y,Z)
Volume = reshape(Volume,xdim,ydim,zdim);

% extract sliceplanes and write COR files

for i = 1:zdim

 % create zero sliceplane
 CORfile = zeros(xdim,ydim);

 % extract the current sliceplane
 %CORfile(:,:) = fliplr(Volume(:,:,i));
  CORfile(:,:) = Volume(:,:,i);

 % create the bfile name
 CORfname = sprintf('%s/%s%03d',pathlocation,'COR-',i);

 disp(['writing file ' num2str(CORfname) '  max: ' num2str(max(CORfile(:))) '  min: ' num2str(min(CORfile(:))) ])

 fid = fopen(CORfname, 'w');
 fwrite(fid, CORfile(:), type);
 fclose(fid);

 
end
